@@ -7,14 +7,14 @@ from src.util import get_valid_filename
 import click
 from termcolor import colored
 
+
 class CustomConfigParser(configparser.ConfigParser):
-    """Modified ConfigParser that allow ':' in keys and only '=' as separator.
-    """
+    """Modified ConfigParser that allow ':' in keys and only '=' as separator."""
+
     OPTCRE = re.compile(
-        r'(?P<option>[^=\s][^=]*)'
-        r'\s*(?P<vi>[=])\s*'
-        r'(?P<value>.*)$'
-        )
+        r"(?P<option>[^=\s][^=]*)" r"\s*(?P<vi>[=])\s*" r"(?P<value>.*)$"
+    )
+
 
 def get_config_file(first=False):
 
@@ -98,6 +98,15 @@ def get_config():
     return config
 
 
+def get_kibbe_config(option: str = ""):
+    config = get_config()
+
+    if config.has_option("kibbe", option):
+        return config.get("kibbe", option)
+
+    return None
+
+
 def persist_config(config_map):
 
     config = get_config_to_save(config_map)
